.. MDH documentation master file, created by
   sphinx-quickstart on Tue Nov 22 14:54:00 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MDH's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   guide
   tutorial
   api
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
